@@ -25,6 +25,7 @@ MouseButtonEventPtr = lltype.Ptr(lltype.ForwardReference())
 MouseMotionEventPtr = lltype.Ptr(lltype.ForwardReference())
 KeyPtr              = lltype.Ptr(lltype.ForwardReference())
 RWopsPtr            = lltype.Ptr(lltype.ForwardReference())
+CursorPtr           = lltype.Ptr(lltype.ForwardReference())
 
 # ------------------------------------------------------------------------------
 
@@ -91,6 +92,8 @@ class CConfig:
 
     RWops = platform.Struct('SDL_RWops', [])
 
+    Cursor = platform.Struct('SDL_Cursor', [])
+
 # ------------------------------------------------------------------------------
 
 for _prefix, _list in _constants.items():
@@ -111,6 +114,7 @@ KeyboardEventPtr.TO.become(KeyboardEvent)
 MouseButtonEventPtr.TO.become(MouseButtonEvent)
 MouseMotionEventPtr.TO.become(MouseMotionEvent)
 RWopsPtr.TO.become(RWops)
+CursorPtr.TO.become(Cursor)
 
 # ------------------------------------------------------------------------------
 
@@ -248,6 +252,24 @@ RWFromFile       = external('SDL_RWFromFile',
                             [rffi.CCHARP, rffi.CCHARP],
                             RWopsPtr)
 
+CreateCursor     = external('SDL_CreateCursor',
+                            [Uint8P, Uint8P,
+                             rffi.INT, rffi.INT,
+                             rffi.INT, rffi.INT],
+                            CursorPtr)
+
+SetCursor        = external('SDL_SetCursor',
+                            [CursorPtr],
+                            lltype.Void)
+
+GetCursor        = external('SDL_GetCursor',
+                            [],
+                            CursorPtr)
+
+FreeCursor       = external('SDL_FreeCursor',
+                            [CursorPtr],
+                            lltype.Void)
+
 # ------------------------------------------------------------------------------
 
 
